This crate defines a macro for annotating fn and impl in order to wrap functions
or methods with an OpenTelemetry context from Python using the pyo3 crate.
Attribute Macros
- pypropagate
- This macro prepends
pyo3_opentelemetry::attach_otel_context_from_pythonto the function or method body, effectively ensuring that the wrapped function or method is executed in the currentOpenTelemetrycontext from the Python side.